// src/app/tab3/tab3.page.ts
import { Component } from '@angular/core';
import { NavController } from '@ionic/angular';
import { UserService } from '../services/user.service';
import { Subscription } from 'rxjs';
@Component({
  selector: 'app-tab3',
  templateUrl: 'tab3.page.html',
  styleUrls: ['tab3.page.scss']
})
export class Tab3Page{

  username: string = ''; // 使用空字符串作为初始值
  userAvatar: string = '';
  userType: string = '';

  private userInfoSubscription!: Subscription;

  constructor(private navCtrl: NavController, private userService: UserService) {}

  ngOnInit() {
    this.userInfoSubscription = this.userService.getUserInfo$().subscribe(userInfo => {
      this.username = userInfo.username || this.username; // 确保不会覆盖已有的值
      this.userAvatar = userInfo.userAvatar || this.userAvatar;
      this.userType = userInfo.userType || this.userType;
    });
  }

  ngOnDestroy() {
    if (this.userInfoSubscription) {
      this.userInfoSubscription.unsubscribe();
    }
  }
  editProfile() {
    console.log('编辑用户资料');
    this.navCtrl.navigateForward('/edit-profile');
  }

  viewHealthRecord() {
    // 处理查看/编辑健康档案的逻辑
    console.log('查看/编辑健康档案');
    // 可以导航到健康档案页面
    this.navCtrl.navigateForward('/health-record');
  }

  viewMedicalServices() {
    // 处理查看医疗服务的逻辑
    console.log('查看医疗服务');
    // 可以导航到医疗服务页面
    this.navCtrl.navigateForward('/medical-services');
  }

  viewPointsAndCoupons() {
    // 处理查看积分与优惠的逻辑
    console.log('查看积分与优惠');
    // 可以导航到积分与优惠页面
    this.navCtrl.navigateForward('/points-and-coupons');
  }

  viewOrders() {
    // 处理查看订单管理的逻辑
    console.log('查看订单管理');
    // 可以导航到订单管理页面
    this.navCtrl.navigateForward('/orders');
  }

  viewPromotions() {
    // 处理查看活动与推广的逻辑
    console.log('查看详情');
    // 可以导航到活动与推广页面
    this.navCtrl.navigateForward('/promotions');
  }

  goToFaq() {
    // 处理跳转到常见问题页面的逻辑
    console.log('跳转到常见问题页面');
    // 可以导航到常见问题页面
    this.navCtrl.navigateForward('/faq');
  }

  goToFeedback() {
    // 处理跳转到意见反馈页面的逻辑
    console.log('跳转到意见反馈页面');
    // 可以导航到意见反馈页面
    this.navCtrl.navigateForward('/feedback');
  }

  inviteFriends() {
    // 处理邀请好友的逻辑
    console.log('邀请好友');
    // 可以弹出分享对话框或导航到邀请好友页面
    this.navCtrl.navigateForward('/invite-friends');
  }

  manageFamily() {
    // 处理家人管理的逻辑
    console.log('家人管理');
    // 可以导航到家人管理页面
    this.navCtrl.navigateForward('/family-management');
  }
}